#[repr(C)]pub struct AHardwareBufferPlane {
pub data: *mut c_void,
pub pixelStride: u32,
pub rowStride: u32,
}Expand description
Holds data for a single image plane.
Fields
data: *mut c_void< Points to first byte in plane
pixelStride: u32< Distance in bytes from the color channel of one pixel to the next
rowStride: u32< Distance in bytes from the first value of one row of the image to