#[repr(transparent)]pub struct AHardwareBufferFormat(pub c_uint);Expand description
Buffer pixel formats.
Tuple Fields
0: c_uintImplementations
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R8G8B8A8_UNORM: AHardwareBufferFormat
pub const R8G8B8A8_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_R8G8B8A8_UNORM OpenGL ES: GL_RGBA8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R8G8B8X8_UNORM: AHardwareBufferFormat
pub const R8G8B8X8_UNORM: AHardwareBufferFormat
32 bits per pixel, 8 bits per channel format where alpha values are ignored (always opaque). Corresponding formats: Vulkan: VK_FORMAT_R8G8B8A8_UNORM OpenGL ES: GL_RGB8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R8G8B8_UNORM: AHardwareBufferFormat
pub const R8G8B8_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_R8G8B8_UNORM OpenGL ES: GL_RGB8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R5G6B5_UNORM: AHardwareBufferFormat
pub const R5G6B5_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_R5G6B5_UNORM_PACK16 OpenGL ES: GL_RGB565
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R16G16B16A16_FLOAT: AHardwareBufferFormat
pub const R16G16B16A16_FLOAT: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_R16G16B16A16_SFLOAT OpenGL ES: GL_RGBA16F
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const R10G10B10A2_UNORM: AHardwareBufferFormat
pub const R10G10B10A2_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_A2B10G10R10_UNORM_PACK32 OpenGL ES: GL_RGB10_A2
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const BLOB: AHardwareBufferFormat
pub const BLOB: AHardwareBufferFormat
Opaque binary blob format. Must have height 1 and one layer, with width equal to the buffer size in bytes. Corresponds to Vulkan buffers and OpenGL buffer objects. Can be bound to the latter using GL_EXT_external_buffer.
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const D16_UNORM: AHardwareBufferFormat
pub const D16_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_D16_UNORM OpenGL ES: GL_DEPTH_COMPONENT16
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const D24_UNORM: AHardwareBufferFormat
pub const D24_UNORM: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_X8_D24_UNORM_PACK32 OpenGL ES: GL_DEPTH_COMPONENT24
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const D24_UNORM_S8_UINT: AHardwareBufferFormat
pub const D24_UNORM_S8_UINT: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_D24_UNORM_S8_UINT OpenGL ES: GL_DEPTH24_STENCIL8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const D32_FLOAT: AHardwareBufferFormat
pub const D32_FLOAT: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_D32_SFLOAT OpenGL ES: GL_DEPTH_COMPONENT32F
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const D32_FLOAT_S8_UINT: AHardwareBufferFormat
pub const D32_FLOAT_S8_UINT: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_D32_SFLOAT_S8_UINT OpenGL ES: GL_DEPTH32F_STENCIL8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const S8_UINT: AHardwareBufferFormat
pub const S8_UINT: AHardwareBufferFormat
Corresponding formats: Vulkan: VK_FORMAT_S8_UINT OpenGL ES: GL_STENCIL_INDEX8
Sourceimpl AHardwareBufferFormat
impl AHardwareBufferFormat
Sourcepub const Y8Cb8Cr8_420: AHardwareBufferFormat
pub const Y8Cb8Cr8_420: AHardwareBufferFormat
YUV 420 888 format. Must have an even width and height. Can be accessed in OpenGL shaders through an external sampler. Does not support mip-maps cube-maps or multi-layered textures.